@@ -6,8 +6,9 @@ from convisoappsec.flow import api
 
 from .deploy import deploy
 from .finding import finding
-from .analysis import analysis
 from .sast import sast
+from .sca import sca
+from .vulnerability import vulnerability
 from .context import pass_flow_context
 from convisoappsec.flowcli import help_option
 
@@ -62,10 +63,11 @@ def cli(flow_context, api_key, api_url, api_insecure):
     flow_context.insecure = api_insecure
 
 
-cli.add_command(analysis)
 cli.add_command(deploy)
 cli.add_command(finding)
 cli.add_command(sast)
+cli.add_command(sca)
+cli.add_command(vulnerability)
 
 cli.epilog = '''
   Run flow COMMAND --help for more information on a command.
